@@ -2,6 +2,7 @@ from .structs import Coin
 
 AAVE = Coin("AAVE")
 ACA = Coin("ACA")
+ACH = Coin("ACH")
 ADA = Coin("ADA")
 AERGO = Coin("AERGO")
 AGLD = Coin("AGLD")
@@ -80,6 +81,7 @@ FLUX = Coin("FLUX")
 FORTH = Coin("FORTH")
 FTM = Coin("FTM")
 FXS = Coin("FXS")
+GAL = Coin("GAL")
 GALA = Coin("GALA")
 GHST = Coin("GHST")
 GLM = Coin("GLM")
@@ -119,6 +121,7 @@ LRC = Coin("LRC")
 LSK = Coin("LSK")
 LTC = Coin("LTC")
 LUNA = Coin("LUNA")
+LUNA2 = Coin("LUNA2")
 LUNC = Coin("LUNC")
 MANA = Coin("MANA")
 MASK = Coin("MASK")
@@ -169,6 +172,7 @@ RARI = Coin("RARI")
 RAY = Coin("RAY")
 REEF = Coin("REEF")
 REN = Coin("REN")
+REP = Coin("REP")
 REQ = Coin("REQ")
 RGT = Coin("RGT")
 RLC = Coin("RLC")
@@ -220,6 +224,7 @@ WBTC = Coin("WBTC")
 WEMIX = Coin("WEMIX")
 WOO = Coin("WOO")
 XLM = Coin("XLM")
+XNO = Coin("XNO")
 XRP = Coin("XRP")
 XTZ = Coin("XTZ")
 XYO = Coin("XYO")
