@@ -5,6 +5,7 @@ AAVE_USDC = Pair("AAVE_USDC", price_precision=2, quantity_precision=4)
 AAVE_USDT = Pair("AAVE_USDT", price_precision=3, quantity_precision=4)
 ACA_BTC = Pair("ACA_BTC", price_precision=9, quantity_precision=2)
 ACA_USDT = Pair("ACA_USDT", price_precision=4, quantity_precision=2)
+ACH_USDT = Pair("ACH_USDT", price_precision=6, quantity_precision=0)
 ADA_BTC = Pair("ADA_BTC", price_precision=9, quantity_precision=0)
 ADA_USDC = Pair("ADA_USDC", price_precision=5, quantity_precision=1)
 ADA_USDT = Pair("ADA_USDT", price_precision=5, quantity_precision=1)
@@ -105,6 +106,7 @@ DOT_BTC = Pair("DOT_BTC", price_precision=7, quantity_precision=4)
 DOT_USDC = Pair("DOT_USDC", price_precision=3, quantity_precision=3)
 DOT_USDT = Pair("DOT_USDT", price_precision=4, quantity_precision=3)
 DYDX_BTC = Pair("DYDX_BTC", price_precision=8, quantity_precision=3)
+DYDX_USDC = Pair("DYDX_USDC", price_precision=3, quantity_precision=3)
 DYDX_USDT = Pair("DYDX_USDT", price_precision=3, quantity_precision=3)
 EFI_BTC = Pair("EFI_BTC", price_precision=9, quantity_precision=2)
 EFI_USDT = Pair("EFI_USDT", price_precision=4, quantity_precision=2)
@@ -131,6 +133,7 @@ ETH_USDT = Pair("ETH_USDT", price_precision=2, quantity_precision=5)
 FARM_USDC = Pair("FARM_USDC", price_precision=2, quantity_precision=4)
 FET_USDT = Pair("FET_USDT", price_precision=5, quantity_precision=1)
 FIL_BTC = Pair("FIL_BTC", price_precision=7, quantity_precision=3)
+FIL_USDC = Pair("FIL_USDC", price_precision=3, quantity_precision=3)
 FIL_USDT = Pair("FIL_USDT", price_precision=3, quantity_precision=3)
 FITFI_BTC = Pair("FITFI_BTC", price_precision=9, quantity_precision=2)
 FITFI_USDT = Pair("FITFI_USDT", price_precision=5, quantity_precision=1)
@@ -148,6 +151,7 @@ FXS_USDT = Pair("FXS_USDT", price_precision=3, quantity_precision=2)
 GALA_BTC = Pair("GALA_BTC", price_precision=9, quantity_precision=1)
 GALA_USDC = Pair("GALA_USDC", price_precision=5, quantity_precision=1)
 GALA_USDT = Pair("GALA_USDT", price_precision=6, quantity_precision=0)
+GAL_USDT = Pair("GAL_USDT", price_precision=4, quantity_precision=2)
 GHST_USDC = Pair("GHST_USDC", price_precision=4, quantity_precision=2)
 GLMR_BTC = Pair("GLMR_BTC", price_precision=9, quantity_precision=2)
 GLMR_USDT = Pair("GLMR_USDT", price_precision=4, quantity_precision=2)
@@ -205,6 +209,8 @@ LSK_USDT = Pair("LSK_USDT", price_precision=4, quantity_precision=2)
 LTC_BTC = Pair("LTC_BTC", price_precision=6, quantity_precision=4)
 LTC_USDC = Pair("LTC_USDC", price_precision=2, quantity_precision=4)
 LTC_USDT = Pair("LTC_USDT", price_precision=2, quantity_precision=5)
+LUNA2_USDC = Pair("LUNA2_USDC", price_precision=4, quantity_precision=2)
+LUNC_USDC = Pair("LUNC_USDC", price_precision=8, quantity_precision=0)
 MANA_BTC = Pair("MANA_BTC", price_precision=9, quantity_precision=1)
 MANA_USDC = Pair("MANA_USDC", price_precision=4, quantity_precision=2)
 MANA_USDT = Pair("MANA_USDT", price_precision=5, quantity_precision=2)
@@ -344,6 +350,7 @@ WOO_USDT = Pair("WOO_USDT", price_precision=5, quantity_precision=1)
 XLM_BTC = Pair("XLM_BTC", price_precision=9, quantity_precision=0)
 XLM_USDC = Pair("XLM_USDC", price_precision=5, quantity_precision=1)
 XLM_USDT = Pair("XLM_USDT", price_precision=5, quantity_precision=1)
+XNO_USDT = Pair("XNO_USDT", price_precision=4, quantity_precision=2)
 XRP_BTC = Pair("XRP_BTC", price_precision=9, quantity_precision=0)
 XRP_USDC = Pair("XRP_USDC", price_precision=5, quantity_precision=1)
 XRP_USDT = Pair("XRP_USDT", price_precision=5, quantity_precision=1)
